Class: StaticSearch::Engine
- Inherits:
-
Rails::Engine
- Object
- Rails::Engine
- StaticSearch::Engine
- Defined in:
- lib/engine.rb
Overview
The engine file add the gem’s migration to the Rails app it is located in
The engine file add the gem’s migration to the Rails app it is located in